definitions library

Classes

AuthorizationMethod
Authorization method configuration. Use this to specify the credentials the SDK uses to authenticate and authorize requests with Glia services.
Queue
Represents a queue with its properties and status.
SiteApiKey
Configuration for the Glia SDK using a site API Key ID and secret.
UserApiKey
Service credential (user) API key authorization configuration.
VisitorInfo
Represents information about a visitor.
VisitorInfoUpdateRequest
Object that can be used for updating the visitor's information on the backend.

Enums

AuthenticationBehavior
Behavior for authentication and deauthentication during engagements.
CustomAttributesUpdateMethod
Specifies a method for updating custom attributes.
MediaType
Supported media types for a queue.
NoteUpdateMethod
Specifies a method for updating the visitor's note.
PushNotificationsIOS
Push notifications environment for iOS.
PushNotificationType
Available push notifications types.
QueueStatus
Status of the queue.

Typedefs

UnreadMessageCountCallback = void Function(int count)
Callback function type for unread message count updates.