SiteApiKey class

Configuration for the Glia SDK using a site API Key ID and secret.

This method is deprecated and will be removed in version 4.0.0. Use UserApiKey instead.

Inheritance
Annotations
  • @Deprecated('Use UserApiKey instead. Will be removed in version 4.0.0.')

Constructors

SiteApiKey({required String id, required String secret})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The site API Key ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
The site API Key secret.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited