UserApiKey class

Service credential (user) API key authorization configuration.

Inheritance

Constructors

UserApiKey({required String id, required String secret})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The service credential (user) API key ID.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
The service credential (user) API key secret.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited